@@ -1,11 +1,13 @@
+use std::borrow::Borrow;
 use windows_sys::{
     Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect,
     Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*,
 };
+use crate::windowclass::WindowClass;
 
 #[cfg(windows)]
 pub struct Window {
-    pub windowclass: PSTR,
+    pub class: WindowClass,
     pub title: String,
     pub width: i32,
     pub height: i32,
@@ -13,14 +15,25 @@ pub struct Window {
     pub y: i32,
 }
 
+#[cfg(linux)]
+pub struct Window {
+    pub class: PSTR,
+    pub title: String,
+    pub width: i32,
+    pub height: i32,
+    pub x: i32,
+    pub y: i32,
+}
+
+#[cfg(windows)]
 impl Window {
 
     ///
     /// Create a new window
     ///
-    pub fn new(windowclass: PSTR, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
+    pub fn new(class: WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
         Self {
-            windowclass,
+            class,
             title,
             width,
             height,
@@ -64,7 +77,6 @@ impl Window {
         self.y
     }
 
-    #[cfg(windows)]
     ///
     /// Display the window
     ///
@@ -74,11 +86,11 @@ impl Window {
     /// use nxui::NativesAndMessaging::*;
     ///
     /// fn main() {
-    ///     let win = nxui::window::Window { windowclass: DEFAULT_WINDOW_WINDOW_CLASS, title: "Hello World".to_string(), width: DEFAULT_WINDOW_WIDTH, height: DEFAULT_WINDOW_HEIGHT, x: DEFAULT_WINDOW_X, y: DEFAULT_WINDOW_Y };
-    ///     win.show(WINDOWSTYLE_OVERLAPPED,"io.github.lattesyobon.nxui");
+    ///     let win = nxui::window::Window { class: DEFAULT_WINDOW_WINDOW_CLASS, title: "Hello World".to_string(), width: DEFAULT_WINDOW_WIDTH, height: DEFAULT_WINDOW_HEIGHT, x: DEFAULT_WINDOW_X, y: DEFAULT_WINDOW_Y };
+    ///     win.show(WINDOWSTYLE_OVERLAPPED);
     /// }
     /// ```
-    pub fn show(&self, window_style: WINDOW_STYLE, _application_id: &str) {
+    pub fn show(&self, window_style: WINDOW_STYLE) {
         extern "system" fn wndproc(
             window: HWND,
             message: u32,
@@ -104,11 +116,11 @@ impl Window {
         unsafe {
             let instance = GetModuleHandleA(std::ptr::null_mut());
             debug_assert!(instance != 0);
-
+            let class = self.class.clone().get_class();
             let wc = WNDCLASSA {
                 hCursor: LoadCursorW(0, IDC_ARROW),
                 hInstance: instance,
-                lpszClassName: self.windowclass,
+                lpszClassName: class,
                 style: CS_HREDRAW | CS_VREDRAW,
                 lpfnWndProc: Some(wndproc),
                 cbClsExtra: 0,
@@ -123,7 +135,7 @@ impl Window {
 
             CreateWindowExA(
                 0,
-                self.windowclass,
+                class,
                 self.title.as_ptr() as _,
                 WS_VISIBLE | window_style,
                 CW_USEDEFAULT,
@@ -144,24 +156,86 @@ impl Window {
         }
     }
 
-    #[cfg(linux)]
-    pub fn show(&self, window_style: WINDOW_STYLE, application_id: &str) {
+}
+
+#[cfg(linux)]
+impl Window {
+
+    ///
+    /// Create a new window
+    ///
+    pub fn new(class: WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
+        Self {
+            class,
+            title,
+            width,
+            height,
+            x,
+            y,
+        }
+    }
+
+    ///
+    /// Returns the title
+    ///
+    pub fn get_title(self) -> String {
+        self.title
+    }
+
+    ///
+    /// Returns the width value.
+    ///
+    pub fn get_width(self) -> i32 {
+        self.width
+    }
+
+    ///
+    /// Returns the height value.
+    ///
+    pub fn get_height(self) -> i32 {
+        self.height
+    }
+
+    ///
+    /// Returns the x value.
+    ///
+    pub fn get_x_pos(self) -> i32 {
+        self.x
+    }
+
+    ///
+    /// Returns the y value.
+    ///
+    pub fn get_y_pos(self) -> i32 {
+        self.y
+    }
+
+    ///
+    /// Display the window
+    ///
+    /// # Examples
+    /// ```
+    /// use nxui::{messagebox, window};
+    /// use nxui::NativesAndMessaging::*;
+    ///
+    /// fn main() {
+    ///     let win = nxui::window::Window { class: DEFAULT_WINDOW_WINDOW_CLASS, title: "Hello World".to_string(), width: DEFAULT_WINDOW_WIDTH, height: DEFAULT_WINDOW_HEIGHT, x: DEFAULT_WINDOW_X, y: DEFAULT_WINDOW_Y };
+    ///     win.show(WINDOWSTYLE_OVERLAPPED);
+    /// }
+    /// ```
+    pub fn show(&self, window_style: WINDOW_STYLE) {
         use gtk::prelude::*;
 
-        fn build_ui(application: &gtk::Application) {
-            let window = gtk::ApplicationWindow::new(application);
+        let window = gtk::ApplicationWindow::new(application);
 
-            window.set_title(&*self.title);
-            window.set_border_width(10);
-            window.set_position(gtk::WindowPosition::Center);
-            window.set_default_size(self.width, self.height);
+        window.set_title(&*self.title);
+        window.set_border_width(10);
+        window.set_position(gtk::WindowPosition::Center);
+        window.set_default_size(self.width, self.height);
 
-            window.show_all();
-        }
+        window.show_all();
 
-        let application = gtk::Application::new(Some(application_id), Default::default());
-
-        application.connect_activate(build_ui);
+        let application = gtk::Application::new(Some(self.class.clone().get_application_id()), Default::default());
 
         application.run();
     }
